@@ -1,8 +1,10 @@
+import numpy as np
 from collections import OrderedDict
+
 from pykin.kinematics.transform import Transform
 from pykin.kinematics import transformation as tf
 from pykin.kinematics import jacobian as jac
-import numpy as np
+
 
 class Kinematics:
     def __init__(self, tree):
@@ -47,19 +49,6 @@ class Kinematics:
         L = [0.27035, 0.069, 0.36435, 0.069, 0.37429, 0.0, 0.38735]  # 0.36830
         L_h = 0.37082  # np.sqrt(L[2] ** 2 + L[3] ** 2)
 
-        # L_Wo_B = 0.278
-        # h_Wo_B = 0.064
-        # H_Wo_B = 1.104
-
-        # T_Wo_BL = np.array([[np.sqrt(2)/2, np.sqrt(2)/2, 0, L_Wo_B],
-        #                     [-np.sqrt(2)/2, np.sqrt(2)/2, 0, -h_Wo_B],
-        #                     [0, 0, 1, H_Wo_B],
-        #                     [0, 0, 0, 1]])
-
-        # T_Wo_BR = np.array([[-np.sqrt(2)/2, np.sqrt(2)/2, 0, -L_Wo_B],
-        #                     [-np.sqrt(2)/2, -np.sqrt(2)/2, 0, -h_Wo_B],
-        #                     [0, 0, 1, H_Wo_B],
-        #                     [0, 0, 0, 1]])
 
         T_BL_0 = np.array([[1, 0, 0, 0], [0, 1, 0, 0], [0, 0, 1, L[0]], [0, 0, 0, 1]])
         T_BR_0 = T_BL_0
@@ -70,12 +59,8 @@ class Kinematics:
         # pose to Transformation matrix
         T_BL_Goal = tf.pose_to_homogeneous(pose)
 
-        # T_0_6 = np.dot(np.dot(np.matrix.transpose(np.dot(T_Wo_BL, T_BL_0)),
-        #                T_Wo_Goal),
-        #                np.matrix.transpose(TM_6_GR))
         T_0_6 = np.dot(np.dot(np.linalg.inv(T_BL_0), T_BL_Goal), np.linalg.inv(TM_6_GL))
 
-        print(T_0_6)
         # position
         x = T_0_6[0, 3]
         y = T_0_6[1, 3]
